@@ -1272,7 +1272,7 @@ static inline double mix(double a, double b, double k)
 
 static inline double wrap(double a, double d)
 {
-    register double r = fmod( a, d );
+    double r = fmod( a, d );
     return ( r < 0.0 ? d + r : ( r > 0.0 ? r : 0.0 ) );
 }
 
