@@ -85,10 +85,10 @@ static void drawGradient(const TQColor &top, const TQColor &bot, bool increase,
 
             r.coords(&rx, &ry, &rx2, &ry2);
 
-            register int rl(rTop << 16);
-            register int gl(gTop << 16);
-            register int bl(bTop << 16);
-            register int i;
+            int rl(rTop << 16);
+            int gl(gTop << 16);
+            int bl(bTop << 16);
+            int i;
 
             int dr(((1<<16) * (bot.red() - rTop)) / size),
                 dg(((1<<16) * (bot.green() - gTop)) / size),
